import os

KAA_DIR = '~/.kaa/'
KAA_SCRIPT = '__kaa__.py'
LOGDIR = 'log'
HISTDIR = 'history'

HIST_FILENAME = 'files'
HIST_DIRNAME = 'dirs'
HIST_SEARCH = 'searchstr'
HIST_REPLACE = 'replstr'
HIST_GREPSTR = 'grepstr'
HIST_GREPDIR = 'grepdir'
HIST_GREPFILES = 'grepfiles'

NEWLINES = ['auto', 'dos', 'unix']
NEWLINE_CHARS = {
    'auto': None,
    'dos': '\r\n',
    'unix': '\n'
}

